# -*- coding: utf-8 -*-


import os
import json


ExcludeDirDict = {
    '.svn': True,
    '.DS_Store': True,
    'engineStart': True,  # 原脚本中提及到，不知道是啥……
}

GenFileExtDict = {
    'png': True,
    'jpg': True,
    'json': True,
    'fnt': True,
    'zip': True,
    'txt': True,
    'mp3': True,
    'wav': True,
    'exml': True,
}

FileExt2TypeDict = {
    'png': 'image',
    'jpg': 'image',
    'fnt': 'font',
    'zip': 'bin',
    'txt': 'text',
    'mp3': 'sound',
    'wav': 'sound',
    'exml': 'text',
}


def GetResNameByPath(path):
    ext = path.split('.')[1]
    if 'json' == ext and ('atlases' in path or 'stage' in path):
        return os.path.split(path)[-1].replace('.', '_')
    else:
        return path


def GetResTypeByPath(path):
    ext = path.split('.')[1]

    if 'json' == ext:
        if 'atlases' in path:
            return 'sheet'
        elif 'stage' in path:
            return 'sheet'
        else:
            return 'json'

    else:
        return FileExt2TypeDict[ext]


def CollectResFiles(dirPath, list, excludePathDict=None):
    if ExcludeDirDict.has_key(os.path.basename(dirPath)):
        return

    for p in os.listdir(dirPath):
        path = os.path.join(dirPath, p)
        path = path.replace('\\', '/')

        if excludePathDict and excludePathDict.has_key(path):
            # print 'exclude: [%s]'%(path)
            continue

        if os.path.isfile(path):
            ext = path.split('.')[1]

            if not GenFileExtDict.has_key(ext):
                continue

            # 'atlases'目录中只处理json类型的资源文件
            if ('atlases' in path or 'stage' in path) and 'json' != ext:
                continue

            print path
            list.append(path)

        elif os.path.isdir(path):
            CollectResFiles(path, list, excludePathDict)


def GenOneGroupJsonObj(groupName, resNameList):
    obj = {}
    obj['name'] = groupName
    obj['keys'] = ','.join(resNameList)
    return obj


def GenResesJsonObj(resPathList):
    resesJsonObj = []

    for path in resPathList:
        resJObj = {}
        resJObj['name'] = GetResNameByPath(path)
        resJObj['type'] = GetResTypeByPath(path)
        resJObj['url'] = path
        resesJsonObj.append(resJObj)

    return resesJsonObj



def CollectExmlPathsInThemeConfFile(themeConfFilePath):
    ret = None

    if os.path.isfile(themeConfFilePath):
        ret = {}

        f = open(themeConfFilePath, 'r')
        themeConfJson = json.load(f)
        f.close()
        exmls = themeConfJson['exmls']
        for exml in exmls:
            if exml.startswith('resource/'):
                exml = exml[len('resource/'):]
            #print exml
            ret.setdefault(exml, True)

    return ret



def Run():
    groups = []
    excludeExmlPathDict = CollectExmlPathsInThemeConfFile('default.thm.json')

    resPathList = []

    # 从资源目录中搜集
    CollectResFiles('assets', resPathList)
    CollectResFiles('skins', resPathList)
    CollectResFiles('config', resPathList)
    CollectResFiles('stage1', resPathList)

    resesJsonObj = GenResesJsonObj(resPathList)

    resultJObj = {}
    resultJObj['resources'] = resesJsonObj
    resultJObj['groups'] = groups

    confFileName = 'default.res.json'
    f = open(confFileName, 'w')
    f.write( json.dumps(resultJObj, sort_keys=True, indent=2) )
    f.close()

    print('build default.res.json success!')

Run()
